#ifndef _GUI_GCONF_H_
#define _GUI_GCONF_H_

#define kGConfPath "/apps/maemo/psx4all"
#define kGConfRomFile kGConfPath "/" "rom"
#define kGConfBiosFile kGConfPath "/" "bios"
#define kGConfSound kGConfPath "/" "sound"
#define kGConfDisplayFramerate kGConfPath "/" "display-framerate"
#define kGConfGPUStat kGConfPath "/" "gpu-stats"
#define kGConfVMEM kGConfPath "/" "video-mem"
#define kGConfNullGPU kGConfPath "/" "null-gpu"
#define kGConfFrameLimit kGConfPath "/" "frame-limit"
#define kGConfInterlace kGConfPath "/" "interlace"
#define kGConfFrameSkip kGConfPath "/" "frameskip"
#define kGConfFrameSkipLine kGConfPath "/" "frameskipline"
#define kGConfFrameSkipPoly kGConfPath "/" "frameskippoly"
#define kGConfFrameSkipSprite kGConfPath "/" "frameskipsprite"
#define kGConfFrameSkipImage kGConfPath "/" "frameskipimage"
#define kGConfFrameSkipBlit kGConfPath "/" "frameskipblit"
#define kGConfWallClock kGConfPath "/" "wallclock-timing"
#define kGConfAbbeyFix kGConfPath "/" "fix-abbey"
#define kGConfCycleMultiplier kGConfPath "/" "cycle-multiplier"

#define kGConfPlayerPathBufferLen 128
#define kGConfPlayerPath kGConfPath "/player%d"

#define kGConfPlayerKeyboardPath "/" "keyboard"
#define kGConfPlayerKeyboardEnable kGConfPlayerKeyboardPath "/" "enable"

#endif

